You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by ni...@apache.org on 2012/09/12 10:15:48 UTC

svn commit: r1383837 - in /camel/branches/camel-2.10.x: ./ components/camel-http4/src/main/java/org/apache/camel/component/http4/HttpComponent.java components/camel-http4/src/main/java/org/apache/camel/component/http4/HttpEndpoint.java

Author: ningjiang
Date: Wed Sep 12 08:15:48 2012
New Revision: 1383837

URL: http://svn.apache.org/viewvc?rev=1383837&view=rev
Log:
Merged revisions 1383826 via svnmerge from 
https://svn.apache.org/repos/asf/camel/trunk

........
  r1383826 | ningjiang | 2012-09-12 15:59:37 +0800 (Wed, 12 Sep 2012) | 1 line
  
  CAMEL-5596 using https and http as the schema for http proxy
........

Modified:
    camel/branches/camel-2.10.x/   (props changed)
    camel/branches/camel-2.10.x/components/camel-http4/src/main/java/org/apache/camel/component/http4/HttpComponent.java
    camel/branches/camel-2.10.x/components/camel-http4/src/main/java/org/apache/camel/component/http4/HttpEndpoint.java

Propchange: camel/branches/camel-2.10.x/
------------------------------------------------------------------------------
  Merged /camel/trunk:r1383826

Propchange: camel/branches/camel-2.10.x/
------------------------------------------------------------------------------
Binary property 'svnmerge-integrated' - no diff available.

Modified: camel/branches/camel-2.10.x/components/camel-http4/src/main/java/org/apache/camel/component/http4/HttpComponent.java
URL: http://svn.apache.org/viewvc/camel/branches/camel-2.10.x/components/camel-http4/src/main/java/org/apache/camel/component/http4/HttpComponent.java?rev=1383837&r1=1383836&r2=1383837&view=diff
==============================================================================
--- camel/branches/camel-2.10.x/components/camel-http4/src/main/java/org/apache/camel/component/http4/HttpComponent.java (original)
+++ camel/branches/camel-2.10.x/components/camel-http4/src/main/java/org/apache/camel/component/http4/HttpComponent.java Wed Sep 12 08:15:48 2012
@@ -130,8 +130,8 @@ public class HttpComponent extends Heade
     private HttpClientConfigurer configureHttpProxy(Map<String, Object> parameters, HttpClientConfigurer configurer, boolean secure) throws Exception {
         String proxyAuthScheme = getAndRemoveParameter(parameters, "proxyAuthScheme", String.class);
         if (proxyAuthScheme == null) {
-            // fallback and use either http4 or https4 depending on secure
-            proxyAuthScheme = secure ? "https4" : "http4";
+            // fallback and use either http or https depending on secure
+            proxyAuthScheme = secure ? "https" : "http";
         }
         String proxyAuthHost = getAndRemoveParameter(parameters, "proxyAuthHost", String.class);
         Integer proxyAuthPort = getAndRemoveParameter(parameters, "proxyAuthPort", Integer.class);

Modified: camel/branches/camel-2.10.x/components/camel-http4/src/main/java/org/apache/camel/component/http4/HttpEndpoint.java
URL: http://svn.apache.org/viewvc/camel/branches/camel-2.10.x/components/camel-http4/src/main/java/org/apache/camel/component/http4/HttpEndpoint.java?rev=1383837&r1=1383836&r2=1383837&view=diff
==============================================================================
--- camel/branches/camel-2.10.x/components/camel-http4/src/main/java/org/apache/camel/component/http4/HttpEndpoint.java (original)
+++ camel/branches/camel-2.10.x/components/camel-http4/src/main/java/org/apache/camel/component/http4/HttpEndpoint.java Wed Sep 12 08:15:48 2012
@@ -127,9 +127,9 @@ public class HttpEndpoint extends Defaul
             String host = getCamelContext().getProperties().get("http.proxyHost");
             int port = Integer.parseInt(getCamelContext().getProperties().get("http.proxyPort"));
             String scheme = getCamelContext().getProperties().get("http.proxyScheme");
             // fallback and use either http4 or https4 depending on secure
             if (scheme == null) {
-                scheme = HttpHelper.isSecureConnection(getEndpointUri()) ? "https4" : "http4";
+                scheme = HttpHelper.isSecureConnection(getEndpointUri()) ? "https" : "http";
             }
             LOG.debug("CamelContext properties http.proxyHost, http.proxyPort, and http.proxyScheme detected. Using http proxy host: {} port: {} scheme: {}", new Object[]{host, port, scheme});
             try {
@@ -127,9 +127,9 @@ public class HttpEndpoint extends Defaul
             int port = Integer.parseInt(getCamelContext().getProperties().get("http.proxyPort"));
             String scheme = getCamelContext().getProperties().get("http.proxyScheme");
-            // fallback and use either http4 or https4 depending on secure
+            // fallback and use either http or https depending on secure
             if (scheme == null) {